==> pyeccodes-0.0.6.tar.gz: pyeccodes-0.0.6/pyeccodes/defs/grib2/tables/2/4_8_table.py <==
def load(h):
    return ({'abbr': 0, 'code': 0, 'title': 'Anomaly correlation'},
            {'abbr': 1, 'code': 1, 'title': 'Root mean square'},
            {'abbr': 192, 'code': 192, 'title': 'Reserved for local use'},
            {'abbr': 193, 'code': 193, 'title': 'Reserved for local use'},
            {'abbr': 194, 'code': 194, 'title': 'Reserved for local use'},
            {'abbr': 195, 'code': 195, 'title': 'Reserved for local use'},
            {'abbr': 196, 'code': 196, 'title': 'Reserved for local use'},
            {'abbr': 197, 'code': 197, 'title': 'Reserved for local use'},
            {'abbr': 198, 'code': 198, 'title': 'Reserved for local use'},
            {'abbr': 199, 'code': 199, 'title': 'Reserved for local use'},
            {'abbr': 200, 'code': 200, 'title': 'Reserved for local use'},
            {'abbr': 201, 'code': 201, 'title': 'Reserved for local use'},
            {'abbr': 202, 'code': 202, 'title': 'Reserved for local use'},
            {'abbr': 203, 'code': 203, 'title': 'Reserved for local use'},
            {'abbr': 204, 'code': 204, 'title': 'Reserved for local use'},
            {'abbr': 205, 'code': 205, 'title': 'Reserved for local use'},
            {'abbr': 206, 'code': 206, 'title': 'Reserved for local use'},
            {'abbr': 207, 'code': 207, 'title': 'Reserved for local use'},
            {'abbr': 208, 'code': 208, 'title': 'Reserved for local use'},
            {'abbr': 209, 'code': 209, 'title': 'Reserved for local use'},
            {'abbr': 210, 'code': 210, 'title': 'Reserved for local use'},
            {'abbr': 211, 'code': 211, 'title': 'Reserved for local use'},
            {'abbr': 212, 'code': 212, 'title': 'Reserved for local use'},
            {'abbr': 213, 'code': 213, 'title': 'Reserved for local use'},
            {'abbr': 214, 'code': 214, 'title': 'Reserved for local use'},
            {'abbr': 215, 'code': 215, 'title': 'Reserved for local use'},
            {'abbr': 216, 'code': 216, 'title': 'Reserved for local use'},
            {'abbr': 217, 'code': 217, 'title': 'Reserved for local use'},
            {'abbr': 218, 'code': 218, 'title': 'Reserved for local use'},
            {'abbr': 219, 'code': 219, 'title': 'Reserved for local use'},
            {'abbr': 220, 'code': 220, 'title': 'Reserved for local use'},
            {'abbr': 221, 'code': 221, 'title': 'Reserved for local use'},
            {'abbr': 222, 'code': 222, 'title': 'Reserved for local use'},
            {'abbr': 223, 'code': 223, 'title': 'Reserved for local use'},
            {'abbr': 224, 'code': 224, 'title': 'Reserved for local use'},
            {'abbr': 225, 'code': 225, 'title': 'Reserved for local use'},
            {'abbr': 226, 'code': 226, 'title': 'Reserved for local use'},
            {'abbr': 227, 'code': 227, 'title': 'Reserved for local use'},
            {'abbr': 228, 'code': 228, 'title': 'Reserved for local use'},
            {'abbr': 229, 'code': 229, 'title': 'Reserved for local use'},
            {'abbr': 230, 'code': 230, 'title': 'Reserved for local use'},
            {'abbr': 231, 'code': 231, 'title': 'Reserved for local use'},
            {'abbr': 232, 'code': 232, 'title': 'Reserved for local use'},
            {'abbr': 233, 'code': 233, 'title': 'Reserved for local use'},
            {'abbr': 234, 'code': 234, 'title': 'Reserved for local use'},
            {'abbr': 235, 'code': 235, 'title': 'Reserved for local use'},
            {'abbr': 236, 'code': 236, 'title': 'Reserved for local use'},
            {'abbr': 237, 'code': 237, 'title': 'Reserved for local use'},
            {'abbr': 238, 'code': 238, 'title': 'Reserved for local use'},
            {'abbr': 239, 'code': 239, 'title': 'Reserved for local use'},
            {'abbr': 240, 'code': 240, 'title': 'Reserved for local use'},
            {'abbr': 241, 'code': 241, 'title': 'Reserved for local use'},
            {'abbr': 242, 'code': 242, 'title': 'Reserved for local use'},
            {'abbr': 243, 'code': 243, 'title': 'Reserved for local use'},
            {'abbr': 244, 'code': 244, 'title': 'Reserved for local use'},
            {'abbr': 245, 'code': 245, 'title': 'Reserved for local use'},
            {'abbr': 246, 'code': 246, 'title': 'Reserved for local use'},
            {'abbr': 247, 'code': 247, 'title': 'Reserved for local use'},
            {'abbr': 248, 'code': 248, 'title': 'Reserved for local use'},
            {'abbr': 249, 'code': 249, 'title': 'Reserved for local use'},
            {'abbr': 250, 'code': 250, 'title': 'Reserved for local use'},
            {'abbr': 251, 'code': 251, 'title': 'Reserved for local use'},
            {'abbr': 252, 'code': 252, 'title': 'Reserved for local use'},
            {'abbr': 253, 'code': 253, 'title': 'Reserved for local use'},
            {'abbr': 254, 'code': 254, 'title': 'Reserved for local use'},
            {'abbr': None, 'code': 255, 'title': 'Missing'})

==> pyeccodes-0.0.7.tar.gz: pyeccodes-0.0.7/pyeccodes/defs/grib2/tables/2/5_6_table.py <==
def load(h):
    return ({'abbr': 1, 'code': 1, 'title': 'First-order spatial differencing'},
            {'abbr': 2, 'code': 2, 'title': 'Second-order spatial differencing'},
            {'abbr': 192, 'code': 192, 'title': 'Reserved for local use'},
            {'abbr': 193, 'code': 193, 'title': 'Reserved for local use'},
            {'abbr': 194, 'code': 194, 'title': 'Reserved for local use'},
            {'abbr': 195, 'code': 195, 'title': 'Reserved for local use'},
            {'abbr': 196, 'code': 196, 'title': 'Reserved for local use'},
            {'abbr': 197, 'code': 197, 'title': 'Reserved for local use'},
            {'abbr': 198, 'code': 198, 'title': 'Reserved for local use'},
            {'abbr': 199, 'code': 199, 'title': 'Reserved for local use'},
            {'abbr': 200, 'code': 200, 'title': 'Reserved for local use'},
            {'abbr': 201, 'code': 201, 'title': 'Reserved for local use'},
            {'abbr': 202, 'code': 202, 'title': 'Reserved for local use'},
            {'abbr': 203, 'code': 203, 'title': 'Reserved for local use'},
            {'abbr': 204, 'code': 204, 'title': 'Reserved for local use'},
            {'abbr': 205, 'code': 205, 'title': 'Reserved for local use'},
            {'abbr': 206, 'code': 206, 'title': 'Reserved for local use'},
            {'abbr': 207, 'code': 207, 'title': 'Reserved for local use'},
            {'abbr': 208, 'code': 208, 'title': 'Reserved for local use'},
            {'abbr': 209, 'code': 209, 'title': 'Reserved for local use'},
            {'abbr': 210, 'code': 210, 'title': 'Reserved for local use'},
            {'abbr': 211, 'code': 211, 'title': 'Reserved for local use'},
            {'abbr': 212, 'code': 212, 'title': 'Reserved for local use'},
            {'abbr': 213, 'code': 213, 'title': 'Reserved for local use'},
            {'abbr': 214, 'code': 214, 'title': 'Reserved for local use'},
            {'abbr': 215, 'code': 215, 'title': 'Reserved for local use'},
            {'abbr': 216, 'code': 216, 'title': 'Reserved for local use'},
            {'abbr': 217, 'code': 217, 'title': 'Reserved for local use'},
            {'abbr': 218, 'code': 218, 'title': 'Reserved for local use'},
            {'abbr': 219, 'code': 219, 'title': 'Reserved for local use'},
            {'abbr': 220, 'code': 220, 'title': 'Reserved for local use'},
            {'abbr': 221, 'code': 221, 'title': 'Reserved for local use'},
            {'abbr': 222, 'code': 222, 'title': 'Reserved for local use'},
            {'abbr': 223, 'code': 223, 'title': 'Reserved for local use'},
            {'abbr': 224, 'code': 224, 'title': 'Reserved for local use'},
            {'abbr': 225, 'code': 225, 'title': 'Reserved for local use'},
            {'abbr': 226, 'code': 226, 'title': 'Reserved for local use'},
            {'abbr': 227, 'code': 227, 'title': 'Reserved for local use'},
            {'abbr': 228, 'code': 228, 'title': 'Reserved for local use'},
            {'abbr': 229, 'code': 229, 'title': 'Reserved for local use'},
            {'abbr': 230, 'code': 230, 'title': 'Reserved for local use'},
            {'abbr': 231, 'code': 231, 'title': 'Reserved for local use'},
            {'abbr': 232, 'code': 232, 'title': 'Reserved for local use'},
            {'abbr': 233, 'code': 233, 'title': 'Reserved for local use'},
            {'abbr': 234, 'code': 234, 'title': 'Reserved for local use'},
            {'abbr': 235, 'code': 235, 'title': 'Reserved for local use'},
            {'abbr': 236, 'code': 236, 'title': 'Reserved for local use'},
            {'abbr': 237, 'code': 237, 'title': 'Reserved for local use'},
            {'abbr': 238, 'code': 238, 'title': 'Reserved for local use'},
            {'abbr': 239, 'code': 239, 'title': 'Reserved for local use'},
            {'abbr': 240, 'code': 240, 'title': 'Reserved for local use'},
            {'abbr': 241, 'code': 241, 'title': 'Reserved for local use'},
            {'abbr': 242, 'code': 242, 'title': 'Reserved for local use'},
            {'abbr': 243, 'code': 243, 'title': 'Reserved for local use'},
            {'abbr': 244, 'code': 244, 'title': 'Reserved for local use'},
            {'abbr': 245, 'code': 245, 'title': 'Reserved for local use'},
            {'abbr': 246, 'code': 246, 'title': 'Reserved for local use'},
            {'abbr': 247, 'code': 247, 'title': 'Reserved for local use'},
            {'abbr': 248, 'code': 248, 'title': 'Reserved for local use'},
            {'abbr': 249, 'code': 249, 'title': 'Reserved for local use'},
            {'abbr': 250, 'code': 250, 'title': 'Reserved for local use'},
            {'abbr': 251, 'code': 251, 'title': 'Reserved for local use'},
            {'abbr': 252, 'code': 252, 'title': 'Reserved for local use'},
            {'abbr': 253, 'code': 253, 'title': 'Reserved for local use'},
            {'abbr': 254, 'code': 254, 'title': 'Reserved for local use'},
            {'abbr': None, 'code': 255, 'title': 'Missing'})
